package com.example.demo;

import java.util.Map;

import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import jakarta.servlet.http.HttpServletRequest;

@Controller
public class PierwszyController {
	// Gdy metoda w kontrolerze zwraca napis, a nie osiada adnotacji @ResponseBody,
	// to ten napis jest traktowany jak nazwa szablonu (lub ścieżka do szablonu),
	// który ma być użyty do wygenerowania odpowiedzi.
	
	@RequestMapping("/")
	public String index() {
		return "index.html";
	}
	
	// Gdy metoda posiada adnotację @ResponseBody, to, co zwraca returnem, jest odsyłane jako treść odpowiedzi.
	@RequestMapping("/hello")
	@ResponseBody
	public String hello() {
		return "Hello world";
	}

	@RequestMapping("/ping")
	public String ping(HttpServletRequest request, Model model) {
		// Do metod w kontrolerze można dodawać parametry różnych typów,
		// które "Spring zna" i gdy taki parametr się pojawia, to Spring
		// wywołując metodę przekazuje nam w tym parametrze odpowiedni obiekt.
		// To się nazywa wstrzykiwanie parametrów / parameter injection.
		// A ogólnie to podejście, że nie my wywołuemy metodę, aby coś odczytać,
		// tylko spring wywołuje NASZĄ metodę i Spring NAM przekazuje wymagane parametry,
		// nazywa się "inversion of control" (IoC).

		// Przykładowo tutaj dodaliśmy do metody parametr HttpServletRequest
		// i Spring przekazuje nam tu techniczne informacje o zapytaniu (to samo, co
		// było w serwletach).

		// Do modelu można też dodać słownik / mapę.
		// Odczyt wartości wygląda później np. tak ${clientInfo.userAgent}

		String ip = request.getRemoteAddr();
		String host = request.getRemoteHost();
		System.out.println("Zapytanie z adresu " + ip);

		model.addAttribute("clientInfo", Map.of("userAgent", request.getHeader("User-Agent"), "ip", ip, "host", host));
		return "ping.html";
	}

}
